@@ -146,7 +146,7 @@ def get_encoding(data):
         if not np.issubdtype(encoding['dtype'], np.integer):
             raise TypeError('If scale_factor is assigned, then the dtype must be a np.integer.')
 
-    if encoding['dtype'] != h5py.string_dtype():
+    if 'int' in encoding['dtype'].name:
         if ('_FillValue' in encoding) and ('missing_value' not in encoding):
             encoding['missing_value'] = encoding['_FillValue']
 
@@ -271,8 +271,13 @@ def open_file(path, group=None):
             f = path
     elif isinstance(path, xr.Dataset):
         f = path
+    elif isinstance(path, bytes):
+        if isinstance(group, str):
+            f = h5py.File(io.BytesIO(path), 'r')[group]
+        else:
+            f = h5py.File(io.BytesIO(path), 'r')
     else:
-        raise TypeError('path must be a str/pathlib path to an HDF5 file, an h5py.File, or an xarray Dataset.')
+        raise TypeError('path must be a str/pathlib path to an HDF5 file, an h5py.File, a bytes object of an HDF5 file, or an xarray Dataset.')
 
     return f
 
